@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary_conf.cpp,v 1.22 2008-08-04 19:05:33 fredg Exp $
+//      $Id: rdlibrary_conf.cpp,v 1.25.8.1 2014/01/09 01:03:54 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -166,18 +166,6 @@ void RDLibraryConf::setDefaultChannels(unsigned chans) const
 }
 
 
-unsigned RDLibraryConf::defaultSampleRate() const
-{
-  return RDGetSqlValue("RDLIBRARY","ID",lib_id,"DEFAULT_SAMPRATE").toUInt();
-}
-
-
-void RDLibraryConf::setDefaultSampleRate(unsigned rate) const
-{
-  SetRow("DEFAULT_SAMPRATE",rate);
-}
-
-
 unsigned RDLibraryConf::defaultLayer() const
 {
   return RDGetSqlValue("RDLIBRARY","ID",lib_id,"DEFAULT_LAYER").toUInt();
@@ -313,6 +301,44 @@ void RDLibraryConf::setEnableEditor(bool state) const
 }
 
 
+int RDLibraryConf::srcConverter() const
+{
+  return RDGetSqlValue("RDLIBRARY","ID",lib_id,"SRC_CONVERTER").toInt();
+}
+
+
+void RDLibraryConf::setSrcConverter(int conv) const
+{
+  SetRow("SRC_CONVERTER",conv);
+}
+
+
+RDLibraryConf::SearchLimit RDLibraryConf::limitSearch() const
+{
+  return (RDLibraryConf::SearchLimit)
+    RDGetSqlValue("RDLIBRARY","ID",lib_id,"LIMIT_SEARCH").toInt();
+}
+
+
+void RDLibraryConf::setLimitSearch(RDLibraryConf::SearchLimit lmt) const
+{
+  SetRow("LIMIT_SEARCH",(int)lmt);
+}
+
+
+bool RDLibraryConf::searchLimited() const
+{
+  return RDBool(RDGetSqlValue("RDLIBRARY","ID",lib_id,"SEARCH_LIMITED").
+		toString());
+}
+
+
+void RDLibraryConf::setSearchLimited(bool state) const
+{
+  SetRow("SEARCH_LIMITED",RDYesNo(state));
+}
+
+
 void RDLibraryConf::getSettings(RDSettings *s) const
 {
   QString sql;
