@@ -337,6 +337,18 @@ Neu</translation>
         <source>days</source>
         <translation>Tage</translation>
     </message>
+    <message>
+        <source>Missing Username</source>
+        <translation>FehlenderBenutzername</translation>
+    </message>
+    <message>
+        <source>You must specify a username!</source>
+        <translation>Sie müssen einen Benutzernamen angeben!</translation>
+    </message>
+    <message>
+        <source>Update Library Metadata</source>
+        <translation>Bibliotheksmetadaten updaten</translation>
+    </message>
 </context>
 <context>
     <name>EditPlayout</name>
@@ -913,6 +925,18 @@ Neu</translation>
         <source>days</source>
         <translation>Tage</translation>
     </message>
+    <message>
+        <source>Missing Username</source>
+        <translation>FehlenderBenutzername</translation>
+    </message>
+    <message>
+        <source>You must specify a username!</source>
+        <translation>Sie müssen einen Benutzernamen angeben!</translation>
+    </message>
+    <message>
+        <source>Export Library Metadata</source>
+        <translation>Bibliotheksmetadaten exportieren</translation>
+    </message>
 </context>
 <context>
     <name>ListReports</name>
@@ -945,7 +969,7 @@ Neu</translation>
     <name>MainWidget</name>
     <message>
         <source>RDCatch - Host:</source>
-        <translation>RDCatch - Host:</translation>
+        <translation type="obsolete">RDCatch - Host:</translation>
     </message>
     <message>
         <source>rdcatch : </source>
@@ -1229,59 +1253,71 @@ Neu</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>Short Length</source>
-        <translation>Kurze Länge</translation>
+        <translation type="obsolete">Kurze Länge</translation>
     </message>
     <message>
         <source>Low Level</source>
-        <translation>Niedriges Level</translation>
+        <translation type="obsolete">Niedriges Level</translation>
     </message>
     <message>
         <source>High Level</source>
-        <translation>Hohes Level</translation>
+        <translation type="obsolete">Hohes Level</translation>
     </message>
     <message>
         <source>Downloading</source>
-        <translation>Herunterladen</translation>
+        <translation type="obsolete">Herunterladen</translation>
     </message>
     <message>
         <source>Uploading</source>
-        <translation>Hochladen</translation>
+        <translation type="obsolete">Hochladen</translation>
     </message>
     <message>
         <source>Recording</source>
-        <translation>Aufnehmen</translation>
+        <translation type="obsolete">Aufnehmen</translation>
     </message>
     <message>
         <source>Playing</source>
-        <translation>Abspielen</translation>
+        <translation type="obsolete">Abspielen</translation>
     </message>
     <message>
         <source>Waiting</source>
-        <translation>Warten</translation>
+        <translation type="obsolete">Warten</translation>
     </message>
     <message>
         <source>Server Error</source>
-        <translation>Serverfehler</translation>
+        <translation type="obsolete">Serverfehler</translation>
     </message>
     <message>
         <source>Internal Error</source>
-        <translation>Interner Fehler</translation>
+        <translation type="obsolete">Interner Fehler</translation>
     </message>
     <message>
         <source>Interrupted</source>
-        <translation>Unterbrochen</translation>
+        <translation type="obsolete">Unterbrochen</translation>
     </message>
     <message>
         <source>Device Busy</source>
-        <translation>Gerät beschäftigt</translation>
+        <translation type="obsolete">Gerät beschäftigt</translation>
     </message>
     <message>
         <source>No Such Cart/Cut</source>
-        <translation>Kein solcher Cart/Cut</translation>
+        <translation type="obsolete">Kein solcher Cart/Cut</translation>
+    </message>
+    <message>
+        <source>Unknown</source>
+        <translation>Unbekannt</translation>
+    </message>
+    <message>
+        <source>Host</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
