@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: bt16x2.h,v 1.6 2008/09/30 18:19:42 fredg Exp $
+//      $Id: bt16x2.h,v 1.11 2010/08/03 23:39:25 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,37 +23,35 @@
 #ifndef BT16X2_H
 #define BT16X2_H
 
-#include <qobject.h>
-
 #include <rd.h>
 #include <rdmatrix.h>
 #include <rdmacro.h>
 #include <rdtty.h>
 #include <rdoneshot.h>
 
+#include <switcher.h>
+
 #define BT16X2_UNIT_ID 0
 #define BT16X2_POLL_INTERVAL 100
 #define BT16X2_GPIO_PINS 16
 
-class Bt16x2 : public QObject
+class Bt16x2 : public Switcher
 {
  Q_OBJECT
  public:
   Bt16x2(RDMatrix *matrix,QObject *parent=0,const char *name=0);
   ~Bt16x2();
+  RDMatrix::Type type();
+  unsigned gpiQuantity();
+  unsigned gpoQuantity();
+  bool primaryTtyActive();
+  bool secondaryTtyActive();
   void processCommand(RDMacro *cmd);
 
- public slots:
-  void processStatus();
-
- signals:
-  void rmlEcho(RDMacro *cmd);
-  void gpiChanged(int matrix,int line,bool state);
-  void gpoChanged(int matrix,int line,bool state);
-
  private slots:
-  void gpiOneshotData(void *data);
-  void gpoOneshotData(void *data);
+  void processStatus();
+  void gpiOneshotData(int value);
+  void gpoOneshotData(int value);
 
  private:
   RDTTYDevice *bt_device;
