@@ -211,15 +211,17 @@ void rlm_inno713_RLMFree(void *ptr)
 }
 
 
-void rlm_inno713_RLMPadDataSent(void *ptr,const char *svcname,int onair,
-			       int lognum,const struct rlm_pad *now,
-			       const struct rlm_pad *next)
+void rlm_inno713_RLMPadDataSent(void *ptr,const struct rlm_svc *svc,
+			     const struct rlm_log *log,
+			     const struct rlm_pad *now,
+			     const struct rlm_pad *next)
 {
   int i;
   int flag=0;
+  char msg[1500];
 
   for(i=0;i<rlm_inno713_devs;i++) {
-    switch(lognum) {
+    switch(log->log_mach) {
       case 0:
 	flag=rlm_inno713_masters[i];
 	break;
@@ -232,7 +234,7 @@ void rlm_inno713_RLMPadDataSent(void *ptr,const char *svcname,int onair,
 	flag=rlm_inno713_aux2s[i];
 	break;
     }
-    if((flag==1)||((flag==2)&&(onair!=0))) {
+    if((flag==1)||((flag==2)&&(log->log_onair!=0))) {
       rlm_inno713_SendString(ptr,now,next,"DPS",rlm_inno713_dynamicpss+256*i,
 			     rlm_inno713_addresses+i*16,rlm_inno713_ports[i],
 			     rlm_inno713_handles[i]);
@@ -242,6 +244,10 @@ void rlm_inno713_RLMPadDataSent(void *ptr,const char *svcname,int onair,
       rlm_inno713_SendString(ptr,now,next,"TEXT",rlm_inno713_radiotexts+256*i,
 			     rlm_inno713_addresses+i*16,rlm_inno713_ports[i],
 			     rlm_inno713_handles[i]);
+
+      const char *str=RLMResolveNowNext(ptr,now,next,rlm_inno713_pss+256*i);
+      snprintf(msg,1500,"rlm_inno713: sending pad update: \"%s\"",str);
+      RLMLog(ptr,LOG_INFO,msg);
     }
   }
 }
